# Reference

<!--
The content of the {eval-rst} block below is generated by the command:
uv run sphinx-apidoc -T -f -t ./docs/templates -o ./docs ./src
from the root directory.

You need to rerun the command when python files are added, deleted or renamed.
Copy the content from the generated
dapla_toolbelt_metadata.rst file to the {eval-rst} block below and
delete the .rst file afterwards.
-->

```{eval-rst}
dapla\_metadata package
=======================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dapla_metadata.datasets
   dapla_metadata.variable_definitions

Module contents
---------------

.. automodule:: dapla_metadata
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets package
================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dapla_metadata.datasets.external_sources
   dapla_metadata.datasets.utility

Submodules
----------

dapla\_metadata.datasets.code\_list module
------------------------------------------

.. automodule:: dapla_metadata.datasets.code_list
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.config module
--------------------------------------

.. automodule:: dapla_metadata.datasets.config
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.core module
------------------------------------

.. automodule:: dapla_metadata.datasets.core
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.dapla\_dataset\_path\_info module
----------------------------------------------------------

.. automodule:: dapla_metadata.datasets.dapla_dataset_path_info
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.dataset\_parser module
-----------------------------------------------

.. automodule:: dapla_metadata.datasets.dataset_parser
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.model\_backwards\_compatibility module
---------------------------------------------------------------

.. automodule:: dapla_metadata.datasets.model_backwards_compatibility
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.model\_validation module
-------------------------------------------------

.. automodule:: dapla_metadata.datasets.model_validation
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.statistic\_subject\_mapping module
-----------------------------------------------------------

.. automodule:: dapla_metadata.datasets.statistic_subject_mapping
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.user\_info module
------------------------------------------

.. automodule:: dapla_metadata.datasets.user_info
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dapla_metadata.datasets
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.utility package
========================================

Submodules
----------

dapla\_metadata.datasets.utility.constants module
-------------------------------------------------

.. automodule:: dapla_metadata.datasets.utility.constants
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.utility.enums module
---------------------------------------------

.. automodule:: dapla_metadata.datasets.utility.enums
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.utility.utils module
---------------------------------------------

.. automodule:: dapla_metadata.datasets.utility.utils
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dapla_metadata.datasets.utility
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.datasets.external\_sources package
==================================================

Submodules
----------

dapla\_metadata.datasets.external\_sources.external\_sources module
-------------------------------------------------------------------

.. automodule:: dapla_metadata.datasets.external_sources.external_sources
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dapla_metadata.datasets.external_sources
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions package
=============================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dapla_metadata.variable_definitions.generated

Module contents
---------------

.. automodule:: dapla_metadata.variable_definitions
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated package
=======================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dapla_metadata.variable_definitions.generated.vardef_client

Module contents
---------------

.. automodule:: dapla_metadata.variable_definitions.generated
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client package
======================================================================

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   dapla_metadata.variable_definitions.generated.vardef_client.api
   dapla_metadata.variable_definitions.generated.vardef_client.models

Submodules
----------

dapla\_metadata.variable\_definitions.generated.vardef\_client.api\_client module
---------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.api_client
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.api\_response module
-----------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.api_response
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.configuration module
-----------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.configuration
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.exceptions module
--------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.exceptions
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.rest module
--------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.rest
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client
   :members:
   :undoc-members:
   :show-inheritance:


dapla\_metadata.variable\_definitions.generated.vardef\_client.api package
==========================================================================

Submodules
----------

dapla\_metadata.variable\_definitions.generated.vardef\_client.api.data\_migration\_api module
----------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.api.data_migration_api
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.api.draft\_variable\_definitions\_api module
-----------------------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.api.draft_variable_definitions_api
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.api.patches\_api module
--------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.api.patches_api
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.api.public\_api module
-------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.api.public_api
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.api.validity\_periods\_api module
------------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.api.validity_periods_api
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.api.variable\_definitions\_api module
----------------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.api.variable_definitions_api
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.api
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models package
=============================================================================

Submodules
----------

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.complete\_response module
-----------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.complete_response
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.contact module
------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.contact
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.draft module
----------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.draft
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.language\_string\_type module
---------------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.language_string_type
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.owner module
----------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.owner
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.patch module
----------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.patch
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.person module
-----------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.person
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.supported\_languages module
-------------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.supported_languages
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.update\_draft module
------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.update_draft
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.validity\_period module
---------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.validity_period
   :members:
   :undoc-members:
   :show-inheritance:

dapla\_metadata.variable\_definitions.generated.vardef\_client.models.variable\_status module
---------------------------------------------------------------------------------------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models.variable_status
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: dapla_metadata.variable_definitions.generated.vardef_client.models
   :members:
   :undoc-members:
   :show-inheritance:


```
